Struct conjure_runtime::blocking::BodyWriter [−][src]
pub struct BodyWriter { /* fields omitted */ }The blocking writer passed to Body::write.
Implementations
impl BodyWriter[src]
impl BodyWriter[src]pub fn write_bytes(&mut self, buf: Bytes) -> Result<()>[src]
Writes a block of body bytes.
Compared to the Write implementation, this method avoids some copies if the caller already has the body in
Bytes objects.