Struct conjure_runtime::blocking::ResponseBody [−][src]
pub struct ResponseBody<B = DefaultRawBody>(_);
A blocking streaming response body.
Implementations
impl<B> ResponseBody<B> where
B: Body<Data = Bytes>,
B::Error: Into<Box<dyn Error + Sync + Send>>, [src]
impl<B> ResponseBody<B> where
B: Body<Data = Bytes>,
B::Error: Into<Box<dyn Error + Sync + Send>>, [src]pub fn read_bytes(&mut self) -> Result<Option<Bytes>>[src]
Reads the next chunk of bytes from the response.
Compared to the Read implementation, this method avoids some copies of the body data when working with an API
that already consumes Bytes objects.