Struct conjure_runtime::config::ServicesConfig [−][src]
pub struct ServicesConfig { /* fields omitted */ }Configuration for a collection of services.
This type can be constructed programmatically via the ServicesConfigBuilder API or deserialized from e.g. a
configuration file. Default values for various configuration options can be set at the top level in addition to
being specified per-service.
Examples
services:
auth-service:
uris:
- https://auth.my-network.com:1234/auth-service
cache-service:
uris:
- https://cache-1.my-network.com/cache-service
- https://cache-2.my-network.com/cache-service
request-timeout: 10s
# options set at this level will apply as defaults to all configured services
security:
ca-file: var/security/ca.pem
Implementations
impl ServicesConfig[src]
impl ServicesConfig[src]pub fn builder() -> ServicesConfigBuilder[src]
Returns a new builder.
pub fn merged_service(&self, name: &str) -> Option<ServiceConfig>[src]
Returns the configuration for the specified service with top-level defaults applied.
pub fn security(&self) -> Option<&SecurityConfig>[src]
Returns the security configuration.
pub fn proxy(&self) -> Option<&ProxyConfig>[src]
Returns the proxy configuration.
pub fn connect_timeout(&self) -> Option<Duration>[src]
Returns the connection timeout.
pub fn read_timeout(&self) -> Option<Duration>[src]
Returns the read timeout.
pub fn write_timeout(&self) -> Option<Duration>[src]
Returns the write timeout.
pub fn backoff_slot_size(&self) -> Option<Duration>[src]
Returns the backoff slot size.