Enum conjure_runtime::NodeSelectionStrategy [−][src]
#[non_exhaustive]
pub enum NodeSelectionStrategy {
PinUntilError,
PinUntilErrorWithoutReshuffle,
Balanced,
}Specifies the strategy used to select a node of a service to use for a request attempt.
Variants (Non-exhaustive)
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pin to a single host as long as it continues to successfully respond to requests.
If the pinned node fails to successfully respond, the client will rotate through the other nodes until it finds one that can successfully respond and then pin to that new node. The pinned node will also be randomly rotated periodically to help spread load across the cluster.
This is the default behavior.
Like PinUntilError except that the pinned node is never randomly shuffled.
For each new request, select the “next” node (in some unspecified order).