Enum conjure_runtime::ServerQos [−][src]
#[non_exhaustive]
pub enum ServerQos {
AutomaticRetry,
Propagate429And503ToCaller,
}Specifies the behavior of a client in response to a QoS error from a server.
QoS errors have status codes 429 or 503.
Variants (Non-exhaustive)
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The client will automatically retry the request when possible in response to a QoS error.
This is the default behavior.
The client will transparently propagate the QoS error without retrying.
This is designed for use when an upstream service has better context on how to handle a QoS error. Propagating the error upstream to that service without retrying allows it to handle retry logic internally.