Enum conjure_runtime::ServiceError [−][src]
#[non_exhaustive]
pub enum ServiceError {
WrapInNewError,
PropagateToCaller,
}Specifies the behavior of the client in response to a service error from a server.
Service errors are encoded as responses with a 4xx or 5xx response code and a body containing a SerializableError.
Variants (Non-exhaustive)
The service error will be propagated as a new internal service error.
The error’s cause will contain the information about the received service error, but the error constructed by the client will have a different error instance ID, type, etc.
This is the default behavior.
The service error will be transparently propagated without change.
This is designed for use when proxying a request to another node, commonly of the same service. By preserving the original error’s instance ID, type, etc, the upstream service will be able to process the error properly.