Struct conjure_runtime::raw::DefaultRawClient [−][src]
pub struct DefaultRawClient(_);
The default raw client implementation used by conjure_runtime.
This is currently implemented with hyper and openssl, but that is subject to change at any time.