Struct conjure_runtime::Client [−][src]
pub struct Client<T = DefaultRawClient> { /* fields omitted */ }
An asynchronous HTTP client to a remote service.
It implements the Conjure AsyncClient trait, but also offers a “raw” request interface for use with services that
don’t provide Conjure service definitions.
Implementations
impl<T> Client<T>[src]
impl<T> Client<T>[src]pub fn request(
&self,
method: Method,
pattern: &'static str
) -> RequestBuilder<'_, T>[src]
&self,
method: Method,
pattern: &'static str
) -> RequestBuilder<'_, T>
Returns a new request builder.
The pattern argument is a template for the request path. The param method on the builder is used to fill
in the parameters in the pattern with dynamic values.
pub fn get(&self, pattern: &'static str) -> RequestBuilder<'_, T>[src]
Returns a new builder for a GET request.
pub fn post(&self, pattern: &'static str) -> RequestBuilder<'_, T>[src]
Returns a new builder for a POST request.
pub fn put(&self, pattern: &'static str) -> RequestBuilder<'_, T>[src]
Returns a new builder for a PUT request.
pub fn delete(&self, pattern: &'static str) -> RequestBuilder<'_, T>[src]
Returns a new builder for a DELETE request.
pub fn patch(&self, pattern: &'static str) -> RequestBuilder<'_, T>[src]
Returns a new builder for a PATCH request.