Struct conjure_runtime::HostMetrics [−][src]
pub struct HostMetrics { /* fields omitted */ }Metrics about requests made to a specific host of a service.
Implementations
impl HostMetrics[src]
impl HostMetrics[src]pub fn service_name(&self) -> &str[src]
Returns the name of the service running on this host.
pub fn hostname(&self) -> &str[src]
Returns the hostname of the node.
pub fn port(&self) -> u16[src]
Returns the port of the node.
pub fn last_update(&self) -> Instant[src]
Returns the time of the last update to the node’s health metrics.
pub fn response_1xx(&self) -> &Timer[src]
Returns a timer recording requests to this host which returned a 1xx HTTP response.
pub fn response_2xx(&self) -> &Timer[src]
Returns a timer recording requests to this host which returned a 2xx HTTP response.
pub fn response_3xx(&self) -> &Timer[src]
Returns a timer recording requests to this host which returned a 3xx HTTP response.
pub fn response_4xx(&self) -> &Timer[src]
Returns a timer recording requests to this host which returned a 4xx HTTP response (other than 429).
pub fn response_5xx(&self) -> &Timer[src]
Returns a timer recording requests to this host which returned a 5xx HTTP response (other than 503).
pub fn response_qos(&self) -> &Timer[src]
Returns a timer recording requests to this host which returned a QoS error (a 429 or 503).
pub fn response_other(&self) -> &Timer[src]
Returns a timer recording requests to this host which returned an HTTP response not in the range 100-599.
pub fn io_error(&self) -> &Meter[src]
Returns a meter recording requests to this host which returned an IO error.