Struct conjure_runtime::config::SecurityConfig [−][src]
pub struct SecurityConfig { /* fields omitted */ }Security configuration used to communicate with a service.
Implementations
impl SecurityConfig[src]
impl SecurityConfig[src]pub fn builder() -> SecurityConfigBuilder[src]
Returns a new builder.
pub fn ca_file(&self) -> Option<&Path>[src]
The path to a file containing PEM-formatted root certificates trusted to identify the service.
These certificates are used in addition to the system’s root CA list.
pub fn key_file(&self) -> Option<&Path>[src]
The path to a file containing a PEM-formatted private key used for client certificate authentication.
This key is expected to match the leaf certificate in Self::cert_file.
pub fn cert_file(&self) -> Option<&Path>[src]
The path to a file containing PEM-formatted certificates used for client certificate authentication.
The file should start with the leaf certificate corresponding to the key in Self::key_file, and the contain
the remainder of the certificate chain to a trusted root.